Method: Amico::Configuration#default_scope_key

Defined in:
lib/amico/configuration.rb

#default_scope_keyObject

Default key used in Redis for tracking scope for the given relationship calls.

Returns:

  • the default key used in Redis for tracking scope for the given relationship calls.



121
122
123
# File 'lib/amico/configuration.rb', line 121

def default_scope_key
  @default_scope_key ||= 'default'
end